/*
 * Objects of class PC has a number of function that uses componentList that
 * contains all the HardwareComponents in the PC.
 */

import java.util.*;

public class PC {

	private LinkedList componentList = new LinkedList();

	private String manufactor;

	private String model;

	private double price;

	/**
	 * Empty constructor
	 */
	public PC() {
	}

	/**
	 * Constructor, that creates an bobject from manufactor and model
	 * 
	 * @param newManufactor
	 * @param newModel
	 */
	public PC(String newManufactor, String newModel) {
		manufactor = newManufactor;
		model = newModel;
	}

	/**
	 * Returns textual representation of object.
	 * 
	 * @return String
	 */
	protected String description() {
		return "Manufactor:" + manufactor + "\nModel: " + model + "\nPrice:"
				+ price + "\n";
	}

	/**
	 * Caculates price of pc.
	 */
	protected void calculateNewPrice() {
		double newPrice = 0;

		for (int i = 0; i < componentList.size(); i++) {

			HardwareComponent thisComponent = (HardwareComponent) componentList
					.get(i);
			newPrice = newPrice + thisComponent.getPrice();
		}
		price = newPrice;
	}

	/**
	 * Add a component to to component list
	 * 
	 * @param newHardwareComponent
	 */
	protected void addComponent(HardwareComponent newHardwareComponent) {
		componentList.add(newHardwareComponent);
		calculateNewPrice();
	}

	/**
	 * Checks if pc has motherboard.
	 * 
	 * @return boolean
	 */
	protected boolean hasMotherboard() {

		boolean present = false;
		int i;

		for (i = 0; i < componentList.size(); i++) {

			HardwareComponent thisComponent = (HardwareComponent) componentList
					.get(i);

			if ((thisComponent.getClass().getName()).equals("Motherboard")) {
				present = true;
			}
		}
		return present;
	}

	/**
	 * Returns hardware component no given index number
	 * 
	 * @param componentIndex
	 * @return HardwareComponent
	 */
	protected HardwareComponent getComponent(int componentIndex) {

		return (HardwareComponent) componentList.get(componentIndex);
	}

	/**
	 * Returns number of components
	 * 
	 * @return int
	 */
	public int getNumberOfComponents() {

		return componentList.size();
	}

	/* Get-methods */
	protected String getModel() {
		return model;
	}

	protected String getManufacturer() {
		return manufactor;
	}

	protected double getPrice() {
		return price;
	}

	/* Set-methods */
	protected void setModel(String newModel) {
		model = newModel;
	}

	protected void setManufactor(String newManufacturer) {
		manufactor = newManufacturer;
	}

	protected void setPrice(double newPrice) {
		price = newPrice;
	}

}