package component;

/**
 * Description: Denne klasse er parent for fem andre klasser, nemlig Cpu,
 * Motherboard, Pc, Ram og Harddisk. Den indeholder de variable og metoder der
 * er ens for hver af de nedarvende metoder. Klassen er lavet abstract da der
 * har vret brug for en abstract metode, show(), og fordi der ikke skal
 * instantieres nogle objekter af typen Component.
 */
public abstract class Component {

	protected String make;

	protected String model;

	protected int price;

	/**
	 * Metoden setMake bliver brugt nr et objekt skal have navngivet variablen
	 * make.
	 * 
	 * @param make
	 *            String
	 */
	public void setMake(String make) {
		this.make = make;
	}

	/**
	 * Metoden setModel bliver brugt nr et objekt skal have navngivet variablen
	 * model.
	 * 
	 * @param model
	 *            String
	 */
	public void setModel(String model) {
		this.model = model;
	}

	/**
	 * Metoden setPrice bliver brugt nr et objekt skal have navngivet variablen
	 * price.
	 * 
	 * @param price
	 *            String
	 */
	public void setPrice(int price) {
		this.price = price;
	}

	/**
	 * Metoden getMake bliver brugt nr der skal hentes navnet p et objekts
	 * make.
	 * 
	 * @return String
	 */
	public String getMake() {
		return make;
	}

	/**
	 * Metoden getModel bliver brugt nr der skal hentes navnet p et objekts
	 * modelvariabel.
	 * 
	 * @return String
	 */
	public String getModel() {
		return model;
	}

	/**
	 * Metoden getPrice bliver brugt nr der skal hentes navnet p et objekts
	 * pris variabel.
	 * 
	 * @return String
	 */
	public int getPrice() {
		return price;
	}

	/**
	 * Metoden compareTo undersger om en komponents make og model svarer til
	 * det der bliver givet som parameter. Hvis de gr returneres der true
	 * ellers false.
	 * 
	 * @param make
	 *            String
	 * @param model
	 *            String
	 * @param component
	 *            Component
	 * @return boolean
	 */
	public boolean compareTo(String make, String model, Component component) {

		boolean comparesTo = false;

		if (make.equals(component.getMake())
				& model.equals(component.getModel())) {
			comparesTo = true;
		}
		return comparesTo;
	}

	/**
	 * Metoden show er en abstrakt metode, som eksisterer i hver af de klasser
	 * som arver fra klassen Component. Den er netop abstract fordi kroppen p
	 * metoden er forskellige i hver af de arvende klasser.
	 */
	public abstract void show();

	/**
	 * Dette er Component's constructor der bliver brugt til at oprette objekter
	 * med. Dog er det en abstract klasse og der kan derfor ikke oprettes
	 * objekter af denne type, men denne constructor bliver kaldt fra de arvende
	 * klasser, nr der bliver oprettet objekter af disse forskellige typer.
	 * 
	 * @param make
	 *            String
	 * @param model
	 *            String
	 * @param price
	 *            String
	 */
	public Component(String make, String model, int price) {
		this.make = make;
		this.model = model;
		this.price = price;
	}
}