package component;

import java.util.*;

/**
 * Description: Denne klasse omhandler de Pc objekter der bliver skal oprettes
 * og arbejdes med i systemet. Klassen arver alle dets attributter fra
 * Component, men objekter af denne type kommer derudover ogs til at indeholde
 * andre komponenter, alts objekter af en anden type. Nedarver fra Component.
 */
public class Pc extends Component {

	LinkedList componentList;

	/**
	 * Metoden addComponent benyttes nr der skal tilfjes en komponent til et
	 * Pc objekt. Nr det nskede objek er blevet tilfjet bliver prisen p Pc
	 * objektet opdateret, med prisen p det komponent der er blevet tilfjet.
	 * 
	 * @param component
	 *            Component
	 */
	public void addComponent(Component component) {
		componentList.add(component);
		setPrice(getPrice() + component.getPrice());
	}

	/**
	 * Metoden show i klassen Pc benyttes til at vise egenskaberne for et Pc
	 * objekt p skrmen. Der vises frst fabrikantnavn, modelnavn og den
	 * samlede pris for Pc'en. Dernst vises de komponenter der tilhrer Pc
	 * objektet.
	 */
	public void show() {
		System.out.println("Make: " + getMake() + "\n Model: " + getModel()
				+ "\n Price: " + getPrice());
		for (int i = 0; i < componentList.size(); ++i) {
			Component temp = (Component) componentList.get(i);
			temp.show();
		}
	}

	/**
	 * Constructoren for Pc bliver brugt til at oprette et objekt af typen Pc.
	 * Det oprettes med et fabrikantnavn og et modelnavn og vrdien 0. Disse
	 * bliver brugt til at kalde constructoren i superklassen Component.
	 * Derudover bliver der oprettet en LinkedList der har tilknytning til det
	 * specifikke Pc objekt.
	 * 
	 * @param make
	 *            String
	 * @param model
	 *            String
	 */
	public Pc(String make, String model) {
		super(make, model, 0);
		componentList = new LinkedList();
	}
}